@@ -47,6 +47,9 @@ kGPUSiteNGPU = {
     'ANALY_INFN-T1_GPU': 2 #single queue, no submission parameters, 1 GPU per job
 }
 
+kDefultGridSiteType = ['analysis', 'unified']
+kDefaultGridSiteInfo = ['state', 'status', 'maxinputsize', 'maxmemory', 'maxtime']
+
 #########################################################
 #############    Configuration Defaults    ##############
 #########################################################
@@ -62,10 +65,12 @@ kMetricMode = ['min', 'max']
 
 kDefaultSearchAlgorithm = 'random'
 kDefaultScheduler = 'asynchyperband'
+kGenerators = ['nevergrad', 'skopt', 'hyperopt', 'ax', 'bohb', 'grid']
+kDefaultGenerator = 'nevergrad'
 kDefaultMetric = 'loss'
 kDefaultMetricMode = 'min'
 kDefaultTrials = 1
-
+kDefaultStopping = {'training_iteration': 1}
 
 kDefaultOutDS = 'user.${{RUCIO_ACCOUNT}}.hpogrid.{HPO_PROJECT_NAME}.out.$(date +%Y%m%d%H%M%S)'
 
@@ -155,7 +160,7 @@ kConfigFormat = {
         'stop': {
             'required': False,
             'type': dict,
-            'default': {'training_iteration': 1}
+            'default': kDefaultStopping
         },
         'scheduler_param': {
             'required': False,
@@ -286,6 +291,14 @@ kHPOGridMetadataFormat = ['project_name', 'metric', 'mode', 'task_time_s', 'resu
 
 kGridSiteMetadataFileName = 'userJobMetadata.json' #jobReport.json
 
+kDefaultNonUpdatedArgs = '0'*99
+
+#########################################################
+###############    PanDA Tasks Related    ###############
+#########################################################
+
+kPanDATaskOutputColumns = ['jeditaskid', 'status', 'taskname', 'computingsite', 'site', 'metastruct']
+
 
 #####################################################
 ################    Deprecated      #################
