@@ -7,7 +7,6 @@ import tempfile
 
 import hpogrid
 
-from hpogrid.utils.cli_parser import CLIParser
 from hpogrid.components.defaults import *
 from hpogrid.utils import helper, stylus
 from hpogrid.idds_interface.idds_utils import transpose_config
@@ -15,39 +14,6 @@ from hpogrid.configuration import ProjectConfiguration
 
 class GridHandler():
     
-    _USAGE_ = 'hpogrid submit [-h|--help] [<args>]'
-    _DESCRIPTION_ = 'Tool for grid job submission'    
-    
-    def __init__(self):
-        pass
-
-    def get_parser(self, **kwargs):
-        parser = CLIParser(description=self._DESCRIPTION_,
-                           usage=self._USAGE_, **kwargs) 
-        parser.add_argument('config_input', help='the name of project or configuration'
-                            ' file for grid job submission')               
-        parser.add_argument('-n','--n_jobs', type=int, help='number of jobs to submit',
-            default=1)
-        parser.add_argument('-s','--site', help='site to submit the job to '
-            '(this will override the grid config site setting)', default=None)
-        parser.add_argument('-t','--time', help='same as maxCpuCount in prun which '
-            'specifies the maximum cpu time for a job (prevent being killed by'
-            'looping job detection)', type=int, default=-1)
-        parser.add_argument('-m','--mode', help='mode for job submission (choose between '
-                            '"grid" or "idds"',
-                            choices=['grid','idds'],
-                            default='grid')
-        parser.add_argument('-p','--search_points', help='json file containing a list of '
-                            'search points to evaluate (for non-idds jobs only)', default=None)
-        parser.add_argument('-d','--debug', action='store_true', help='debug mode')        
-        return parser
-
-    def run_parser(self, args=None):
-        parser = self.get_parser()
-        args, extra = parser.parse_known_args(args)
-        args = vars(args)
-        self.submit(**args, extra=extra)
-    
     @staticmethod
     def submit(config_input:str, n_jobs=1, site=None, time=-1, search_points=None, mode='grid', debug=False, extra=[]):
         config = GridHandler.preprocess_config(config_input)
@@ -136,7 +102,7 @@ class GridHandler():
             else:
                 raise ValueError('Invalid site settings: {}'.format(site))
             # specify architecture for gpu/cpu site
-            if 'GPU' in site:
+            if 'GPU' in options['site']:
                 options['architecture'] = 'nvidia-gpu'
         # options excluded from idds configuration file due to
         # possible bash variable expansion
@@ -197,9 +163,8 @@ class GridHandler():
             else:
                 raise ValueError('Invalid site settings: {}'.format(site))
             # specify architecture for gpu/cpu site
-            if 'GPU' in site:
+            if 'GPU' in options['site']:
                 options['architecture'] = 'nvidia-gpu'
-                
         
         command = 'prun {} {}'.format(stylus.join_options(options), ' '.join(extra))
         return command        
