@@ -14,7 +14,6 @@ import ray
 from ray import tune
 
 import hpogrid
-from hpogrid.utils.cli_parser import CLIParser
 from hpogrid.components.defaults import *
 from hpogrid.utils import helper
 from hpogrid.idds_interface import idds_utils
@@ -28,24 +27,6 @@ class JobBuilder():
     def __init__(self, parser=False):
         self.reset()
         
-    def get_parser(self, **kwargs):
-        parser = CLIParser(description=self._DESCRIPTION_,
-                           usage=self._USAGE_, **kwargs)    
-        parser.add_argument('config_input', help='Name of project/configuration file')  
-        parser.add_argument('-p', '--search_points', help='A json file containing the manual'
-                            ' search points to run', default=None)    
-        parser.add_argument('-m', '--mode',  help='Platform for running hyperparameter'
-                            ' optimization. Choose from "local", "grid", "idds"',
-                            choices=['local', 'grid', 'idds'],
-                            default='local')   
-        return parser
-    
-    def run_parser(self, args=None):
-        parser = self.get_parser()
-        args = vars(parser.parse_args(args))
-        self.load(**args)
-        self.run()
-        
     @property
     def algorithm(self) -> str:
         return self._algorithm
@@ -93,13 +74,16 @@ class JobBuilder():
         max_concurrent = min(num_trials, self.max_concurrent)
         for device in ['cpu', 'gpu']:
             n_device = resource[device]
-            if n_device >= self.max_concurrent:
+            if n_device >= max_concurrent:
                 resource_per_trial[device] = int(n_device/max_concurrent)  
             elif n_device > 0:
                 resource_per_trial[device] = n_device/max_concurrent
             else:
                 resource_per_trial[device] = 0
-                
+        # for now only use 1 GPU per trial
+        if self.num_trials == -1:
+            resource_per_trial['gpu'] = 1
+            
         if isinstance(value, dict):
             for device in ['cpu', 'gpu']:
                 if device in value and value[device]:
@@ -176,8 +160,6 @@ class JobBuilder():
         """
         self._log_dir = val
             
-        
-            
     def reset(self):
         self.project_name = None
         # model configuration
@@ -380,6 +362,7 @@ class JobBuilder():
             json.dump({}, output)
         
         temp_dir = tempfile.TemporaryDirectory()
+
         # HPO starts
         try:
             
@@ -389,7 +372,6 @@ class JobBuilder():
             if hpogrid.is_grid_job():
                 datadir = hpogrid.get_datadir()
                 extracted_files = helper.extract_tarball(datadir, datadir)
-                
             ray.init(include_dashboard=False)
 #           lru_evict=True      
             if not self.log_dir:
@@ -418,7 +400,6 @@ class JobBuilder():
             ray.shutdown()
             # remove the extracted tar files
             helper.remove_files(extracted_files)
-        
         end = time.time()
         self._total_time = float(end-start)
         self._end_datetime = datetime.now().strftime("%m/%d/%Y, %H:%M:%S")
@@ -439,7 +420,7 @@ class JobBuilder():
         # save metadata
         with open(summary_output_path, 'w') as output:
             print('INFO: Job metadata is saved at {}'.format(summary_output_path))
-            json.dump(metadata, output, cls=helper.NpEncoder)
+            json.dump(metadata, output, cls=helper.NpEncoder, indent=2)
         
         # save idds output
         if hpogrid.is_idds_job():
@@ -507,7 +488,7 @@ class JobBuilder():
             self.search_points = search_points
             from hpogrid.search_space.skopt_space import SkOptSpace
             skopt_search_points = SkOptSpace.transform(search_points, 
-                                      reference=job.search_space)
+                                      reference=self.search_space)
             self.algorithm = 'skopt'
             self.scheduler = None
             self.scheduler_param = {}
