@@ -30,8 +30,6 @@ try:
 except:
     raise ImportError('No module named \'pandatools\'. Please do '
         '\'setupATLAS\' and \'lsetup panda\' first ')
-    
-from hpogrid.utils.cli_parser import CLIParser
 
 kPanDA_URL = 'https://bigpanda.cern.ch/'
 kPanDA_TaskURL = 'https://bigpanda.cern.ch/tasks/'
@@ -93,68 +91,20 @@ class PandaTaskManager():
     _USAGE_ = 'hpogrid tasks [-h|--help] {action} [<args>]'
     _DESCRIPTION_ = 'Tool for PanDA task management'    
 
-    def __init__(self):
-        print('INFO: Verifying Grid Proxy...')
-        self.pbook = PBookCore.PBookCore()
-        print('INFO: Verification is Successful.')
+    def __init__(self, skip_pbook=False):
+        self.pbook = None
+        if not skip_pbook:
+            self.init_pbook()
         self.context = ssl.SSLContext()
         #self.context = ssl._create_unverified_context()
         self.context.load_verify_locations(**kPanDAVerifyPath)
-            
-    def get_parser(self, **kwargs):
-        usage_str = self._USAGE_.format(action='<action>')
-        parser = CLIParser(description=self._DESCRIPTION_,
-                           usage=usage_str, **kwargs) 
-        parser.set_title('The most commonly used actions are')
-        action_subparser = parser.add_subparsers(dest="action", parser_class=CLIParser)   
-
-        action_parsers = {}
-        for action, msg in self._ACTION_HELP_MESSAGE_.items():
-            usage_str = self._USAGE_.format(action=action)
-            args = {'help': msg, 'description': msg, 'usage': usage_str, 'prog': usage_str}
-            action_parsers[action] = action_subparser.add_parser(action, **args)  
-            
-        action_parsers['show'].add_argument('-u','--username',
-            help='filter tasks by username')
-        action_parsers['show'].add_argument('-l','--limit', type=int, default=1000,
-            help='the maximum number of tasks to query')
-        action_parsers['show'].add_argument('-d', '--days', type=int, default=30,
-            help='filter tasks within the recent N days')
-        action_parsers['show'].add_argument('-n', '--taskname', 
-            help='filter tasks by taskname (accept wildcards)')
-        action_parsers['show'].add_argument('-i', '--jeditaskid',
-            help='only show the task with the specified jeditaskid')
-        action_parsers['show'].add_argument('-m', '--metadata', action='store_true',
-            help='print out the metadata of a task')
-        action_parsers['show'].add_argument('-s', '--status', nargs='+',
-            help='filter tasks by task status')
-        action_parsers['show'].add_argument('-y', '--sync', action='store_true',
-            help='force no caching on the PanDA server')
-        action_parsers['show'].add_argument('-r', '--taskid_range',
-            help='filter tasks by jeditaskid range')
-        action_parsers['show'].add_argument('-o', '--output',
-            help='output result with the filename if specified')
-        action_parsers['show'].add_argument('-c', '--outcol',
-            help='data columns to be saved in output',
-            default=kOutputColumns)
-        
-        for action in ['kill', 'retry', 'killAndRetry']:
-            action_parsers[action].add_argument('jeditaskid', help='JediTaskID of the task')   
-
-        return parser
-            
-    def run_parser(self, args=None):
-        parser = self.get_parser()
-        args = vars(parser.parse_args(args))  
-        action = args.pop('action')
-        if action is None:
-            parser.print_help()
-            sys.exit(0)
-        if not hasattr(self, action):
-            print('Unrecognized action: {}'.format(action))
-            parser.print_help()
-            sys.exit(0)
-        getattr(self, action)(args)        
+    
+    def init_pbook(self):
+        if self.pbook is not None:
+            return
+        print('INFO: Verifying Grid Proxy...')
+        self.pbook = PBookCore.PBookCore()
+        print('INFO: Verification is Successful.')
 
     def get_response(self, req, out_json=True):
         response = urlopen(req, context=self.context).read().decode('utf-8')
@@ -203,11 +153,16 @@ class PandaTaskManager():
     def query_tasks(self, taskname=None, jeditaskid=None, username=None, limit=1000,
                     status=None, superstatus=None, days=30, sync=False, metadata=False, 
                     taskid_range=None, **args):
+        
         if username is None:
             username = self.pbook.username
         
-        _status = status if not isinstance(status, list) else None
-        
+        _status = None
+        if isinstance(status, str):
+            _status = status
+        elif (isinstance(status, list) and len(status) == 1):
+            _status = status[0]
+
         params = { 
         'json': 1,
         'limit':limit,
@@ -334,7 +289,9 @@ class PandaTaskManager():
     # filter task by status
     @staticmethod
     def filter_status(datasets, status):
-        if not isinstance(status, list):
+        if not status:
+            return datasets
+        if isinstance(status, str):
             status = [status]
         datasets = [ds for ds in datasets if ds.get('status', None) in status]
         return datasets    
@@ -356,40 +313,38 @@ class PandaTaskManager():
             json.dump(out_dataset, outfile)
 
     # show task status
-    def show(self, args):
-        output = args.pop('output', None)
-        outcol = args.pop('outcol', None)
+    def show(self, outname=None, outcol=kOutputColumns, **params):
         print('INFO: Fetching PanDA Tasks...')
-        datasets = self.query_tasks(**args)
+        datasets = self.query_tasks(**params)
         
         print('')
         self.print_standard(datasets)
         
-        if args['metadata']:
+        if params['metadata']:
             print('')
-            self.print_metadata(datasets)       
+            self.print_metadata(datasets)
+            
+        print('')
 
-        if output:
+        if outname is not None:
             self.save_datasets(datasets, output, col=outcol)
 
 
     def get_active_tasks(self):
-        return pbookCore.get_active_tasks()
+        return PBookCore.get_active_tasks()
 
-    def kill(self, args):
-        task_id = int(args['jeditaskid'])
+    def kill(self, task_id):
+        self.init_pbook()
         self.pbook.kill(task_id)
 
-    def retry(self, args):
-        task_id = int(args['jeditaskid'])
+    def retry(self, task_id):
+        self.init_pbook()
         self.pbook.retry(task_id)
 
-    def killAndRetry(self, args):
-        task_id = int(args['jeditaskid'])
+    def killAndRetry(self, task_id):
+        self.init_pbook()
         self.pbook.killAndRetry(task_id)
 
-
-
     '''
     def deprecated_query(self, params):
                 req = self.get_request(kPanDA_JobURL, params)
