@@ -7,12 +7,10 @@ import argparse
 import pandas as pd
 from tabulate import tabulate
 
-from hpogrid.utils.cli_parser import CLIParser
 from hpogrid.components.panda_task_manager import PandaTaskManager
 from hpogrid.components.defaults import *
 from hpogrid.components.validation import validate_job_metadata
 
-kDefaultExtraColumns = []
 kSupportedExtraColumns = ['site', 'task_time_s', 'time_s', 'taskid', 'start_timestamp',
                          'start_datetime','end_datetime']
 
@@ -238,75 +236,34 @@ class HPOReport():
 
 class HPOTaskHandle(HPOReport):
     
-    _USAGE_ = 'hpogrid report <project_name> [<args>]'
-    _DESCRIPTION_ = 'Tool for managing HPO result'        
-
     def __init__(self):
         super().__init__()
         self.taskmgr = PandaTaskManager()
-
-    def get_parser(self, **kwargs):
-        parser = CLIParser(description=self._DESCRIPTION_,
-                           usage=self._USAGE_, **kwargs)    
-        parser.add_argument('proj_name', help='Name of the project')
-        parser.add_argument('-l','--limit', type=int, default=1000,
-            help='the maximum number of tasks to query')
-        parser.add_argument('-d', '--days', type=int, default=30,
-            help='filter tasks within the recent N days')
-        parser.add_argument('-n', '--taskname',
-            help='filter tasks by taskname (accept wildcards)')
-        parser.add_argument('-r', '--range',
-            help='filter tasks by jeditaskid range')
-        parser.add_argument('-e', '--extra', nargs='+',
-            default=kDefaultExtraColumns,
-            help='extra data columns to be displayed and saved')
-        parser.add_argument('-s', '--summary', action='store_true',
-            help='save a complete hpo result summary as a json file')        
-        parser.add_argument('-j', '--to_json', action='store_true',
-            help='output result to a json file')
-        parser.add_argument('-t', '--to_html', action='store_true',
-            help='output result to an html file')
-        parser.add_argument('-c', '--to_csv', action='store_true',
-            help='output result to a csv file')
-        parser.add_argument('-p', '--to_pcp', action='store_true',
-            help='output result as a parallel coordinate plot')
-        parser.add_argument('-f', '--to_mlflow', action='store_true',
-            help='output result as an mlflow tracker directory')
-        parser.add_argument('-o', '--outname', default='hpo_result',
-            help='output file name (excluding extension)')
-        parser.add_argument('--min', type=float, default=None,
-            help='filter results by minimum value of metric ')
-        parser.add_argument('--max', type=float, default=None,
-            help='filter results by maximum value of metric ')
-        return parser
-    
-    def run_parser(self, args=None):
-        parser = self.get_parser()
-        args = vars(parser.parse_args(args))
-        self.display(args)
-
-    def display(self, params):
-        params['metadata'] = True
-        params['status'] = ['finished', 'done']
-        proj_name = params.pop('proj_name', '')
-        outname = params.pop('outname', None)
-        datasets = self.taskmgr.query_tasks(**params)
+        
+    def display(self, project_name, outname="hpo_result", metric_min=None,
+                metric_max=None, extra_columns=None, taskid_range=None, 
+                summary=False, to_json=False, to_html=False,
+                to_csv=False, to_pcp=False, to_mlflow=False,
+                **task_params):
+        task_params['metadata'] = True
+        task_params['status'] = ['finished', 'done']
+        datasets = self.taskmgr.query_tasks(**task_params)
         # filter tasks by jetitaskid range
-        if params['range'] is not None:
-            datasets = self.taskmgr.filter_range(datasets, params['range'])
+        if taskid_range is not None:
+            datasets = self.taskmgr.filter_range(datasets, taskid_range)
         col = ['computingsite', 'jobs_metadata', 'jeditaskid', 'site']
         datasets = self.taskmgr.filter_datasets(datasets, col)
-
-        extra_columns = params['extra'] or []
+        
+        extra_columns = extra_columns if extra_columns is not None else []
         for extra in extra_columns:
             if not extra in kSupportedExtraColumns:
                 raise ValueError('Unsupported extra column {}'.format(extra))
 
         skip_time = 'tims_s' not in extra_columns
-        self.parse_datasets(datasets, proj_name, extra_columns=extra_columns)
+        self.parse_datasets(datasets, project_name, extra_columns=extra_columns)
         self.show(extra_columns, skip_time)
 
-        bounds = {'metric_min':params['min'], 'metric_max':params['max']}
+        bounds = {'metric_min':metric_min, 'metric_max':metric_max}
         
         if params['summary']:
             self.to_summary(outname+'_summary.json')
@@ -320,9 +277,9 @@ class HPOTaskHandle(HPOReport):
             self.to_parallel_coordinate_plot(outname+'_parallel_coordinate_plot.html',
                                              extra_columns, skip_time, **bounds)   
         if params['to_mlflow']:
-            self.to_mlflow(extra_columns, skip_time, **bounds)    
+            self.to_mlflow(extra_columns, skip_time, **bounds)
 
-    def filter_invalid_datasets(self, datasets, proj_name):
+    def filter_invalid_datasets(self, datasets, project_name):
         filtered_datasets = []
         metadata_list = []
         for dataset in datasets:
@@ -333,7 +290,7 @@ class HPOTaskHandle(HPOReport):
             # check if it is a valid metadata generated by hpogrid
             # and if the metadata corresponds to the project of concern
             if not all( validate_job_metadata(data) and 
-                       data.get('project_name', None) == proj_name \
+                       data.get('project_name', None) == project_name \
                        for data in metadata):
                 continue
             filtered_datasets.append(dataset)
@@ -372,9 +329,9 @@ class HPOTaskHandle(HPOReport):
                           'Probably the format has changed. Skipping.')
         return metadata_list
 
-    def parse_datasets(self, datasets, proj_name, extra_columns=kDefaultExtraColumns):
+    def parse_datasets(self, datasets, project_name, extra_columns=kDefaultExtraColumns):
         summary = []
-        valid_datasets = self.filter_invalid_datasets(datasets, proj_name)
+        valid_datasets = self.filter_invalid_datasets(datasets, project_name)
 
         metric =  None
         mode = None
