@@ -41,9 +41,9 @@ def validate_config(config, config_type):
     if config_type not in kConfigFormat:
         raise ValueError('Unknown configuration type "{}"'.format(config_type))
     config_format = kConfigFormat[config_type]
-    print('Info: Validating {} configuration'.format(config_type))
+    print('INFO: Validating {} configuration'.format(config_type))
     validate(config, config_format)
-    print('Info: Successfully validated {} configuration'.format(config_type))
+    print('INFO: Successfully validated {} configuration'.format(config_type))
     return config 
 
 def validate_project_config(config):
@@ -55,7 +55,7 @@ def validate_project_config(config):
     return config
         
 def validate_search_space(search_space):
-    print('Info: Validating search space configuration...')
+    print('INFO: Validating search space configuration...')
     config_format = kConfigFormat['search_space']
     sampling_methods = config_format.keys()
     kHPKeys = set(['method', 'dimension'])
@@ -88,7 +88,7 @@ def validate_search_space(search_space):
                           ' the hyperparameter "{}" will be set to its default value {}'.format(
                           arg, method, hp, config_format[method][arg]['default']))
                     search_space[hp]['dimension'][arg] = config_format[method][arg]['default']
-    print('Info: Successfully validated search space configuration')
+    print('INFO: Successfully validated search space configuration')
     return search_space
 
 
