@@ -6,7 +6,6 @@ import json
 from typing import Optional
 import tempfile
 
-from hpogrid.utils.cli_parser import CLIParser
 from hpogrid.components.defaults import *
 from hpogrid.utils import helper, stylus
 from hpogrid.components import environment_settings
@@ -92,25 +91,9 @@ def save_idds_output_from_metadata(metadata):
         json.dump(output, output_file, cls=helper.NpEncoder)
         
 class IDDSInterface():
-    _USAGE_ = 'hpogrid idds_log <task_id>'
-    _DESCRIPTION_ = 'Tool for retrieving iDDS logs'      
     
     @staticmethod
-    def get_parser(**kwargs):
-        parser = CLIParser(description=IDDSInterface._DESCRIPTION_,
-                           usage=IDDSInterface._USAGE_, **kwargs)           
-        parser.add_argument('task_id', help='Task ID for iDDS job', type=int)      
-        return parser
-    
-    @staticmethod
-    def run_parser(args=None):
-        parser = IDDSInterface.get_parser()
-        args = vars(parser.parse_args(args))
-        task_id = args['task_id']
-        IDDSInterface.check_log(workload_id=task_id)
-    
-    @staticmethod
-    def check_log(workload_id:int, request_id=None,
+    def download_log(workload_id:int, request_id=None,
                   idds_config_path=kDefaultiDDSConfigPath,
                   proxy_path=kDefaultProxyPath):
         os.environ['IDDS_CONFIG'] = idds_config_path
@@ -121,10 +104,12 @@ class IDDSInterface():
         host = get_rest_host()
         client = Client(host=host)
 
-        print('INFO: Fetching iDDS log files for the task: {}'.format(workload_id))
+        print('INFO: Fetching iDDS log files for the task with taskID = {}'.format(workload_id))
         filename = client.download_logs(workload_id=workload_id, request_id=request_id, dest_dir='/tmp')
-        print('INFO: iDDS log files can be found at:')
-        print(filename)
+        if not filename:
+            print('INFO: No iDDS log found for the task with taskID = {}'.format(workload_id))
+        else:
+            print('INFO: iDDS log files can be found at: {}'.format(filename))
         if original_proxy:
             os.environ['X509_USER_PROXY'] = original_proxy
         
