@@ -5,11 +5,7 @@ from typing import List, Dict
 import numpy as np
 import argparse
 
-from hpogrid.utils.cli_parser import CLIParser
-
-kDefaultGenerator = 'nevergrad'
-kDefaultMetric = 'loss'
-kDefaultMode = 'min'
+from hpogrid.components.defaults import kDefaultGenerator, kDefaultMetric, kDefaultMetricMode
 
 class NpEncoder(json.JSONEncoder):
     def default(self, obj):
@@ -25,40 +21,8 @@ class NpEncoder(json.JSONEncoder):
             return super(NpEncoder, self).default(obj)
 
 class SteeringIDDS():
-    
-    _USAGE_ = 'hpogrid generate [<args>]'
-    _DESCRIPTION_ = 'Tool for generation of hyperparamter search points based on input search space'
-    
-    def __init__(self):
-        pass
 
-    def get_parser(self, **kwargs):
-        parser = CLIParser(description=self._DESCRIPTION_,
-                           usage=self._USAGE_, **kwargs) 
-        parser.add_argument('-l', '--lib', default=kDefaultGenerator,
-            help='library to use')  
-        parser.add_argument('-s', '--space',
-            help='search space json file')
-        parser.add_argument('-n', '--n_point', type=int, required=True,
-            help='number of points to generate')
-        parser.add_argument('-m', '--max_point', type=int,
-            help='maximum number of points to generate in entire iDDS workflow')
-        parser.add_argument('-e', '--metric', default=kDefaultMetric,
-            help='evaluation metric')
-        parser.add_argument('-d', '--mode', default=kDefaultMode,
-            help='evaluation mode')
-        parser.add_argument('-i', '--infile', help='iDDS input')
-        parser.add_argument('-o', '--outfile', help='iDDS output')
-        parser.add_argument('--method', help='optimizer type (nevergrad only)')
-        return parser
-    
-    def run_parser(self, args=None):
-        parser = self.get_parser()
-        args, extra = parser.parse_known_args(args)
-        args = vars(args)
-        self.run_generator(**args)    
-
-    def get_generator(self, space, metric=kDefaultMetric, mode=kDefaultMode, lib=kDefaultGenerator, **args):
+    def get_generator(self, space, metric=kDefaultMetric, mode=kDefaultMetricMode, lib=kDefaultGenerator, **args):
         if lib == 'nevergrad':
             from hpogrid.generator.nevergrad_generator import NeverGradGenerator
             return NeverGradGenerator(space, metric, mode, **args)
@@ -158,7 +122,7 @@ class SteeringIDDS():
         else:
             raise RuntimeError('Failed to parse idds input')
     
-    def generate_points(self, search_space, n_point, metric=kDefaultMetric, mode=kDefaultMode,
+    def generate_points(self, search_space, n_point, metric=kDefaultMetric, mode=kDefaultMetricMode,
                             lib=kDefaultGenerator, max_point=None, points=None,
                             results=None, **args):
         
@@ -203,7 +167,7 @@ class SteeringIDDS():
         return new_points
 
     def run_generator(self, space, n_point, metric=kDefaultMetric,
-                      mode=kDefaultMode, lib=kDefaultGenerator, max_point=None,
+                      mode=kDefaultMetricMode, lib=kDefaultGenerator, max_point=None,
                       infile=None, outfile=None, **args):
         
         parsed_data = self.parse_idds_input(infile)
