@@ -4,40 +4,11 @@ import json
 import fnmatch
 import argparse
 
-from hpogrid.utils.cli_parser import CLIParser
 from hpogrid.utils import stylus
-
-kDefultGridSiteType = ['analysis', 'unified']
-kDefaultGridSiteInfo = ['state', 'status', 'maxinputsize', 'maxmemory', 'maxtime']
+from hpogrid.components.defaults import kDefultGridSiteType, kDefaultGridSiteInfo
 
 class GridSiteInfo():
     
-    _USAGE_ = 'hpogrid sites [<args>]'
-    _DESCRIPTION_ = 'Tool for retrieving grid site information'      
-    
-    @staticmethod
-    def get_parser(**kwargs):
-        parser = CLIParser(description=GridSiteInfo._DESCRIPTION_,
-                           usage=GridSiteInfo._USAGE_, **kwargs)           
-        parser.add_argument('-n', '--name', metavar='',help='filter grid site names')
-        parser.add_argument('-g', '--non_gpu', action='store_true',
-            help='show also non gpu sites')
-        parser.add_argument('-a', '--non_active', action='store_true',
-            help='show also non active sites')
-        parser.add_argument('-t', '--site_type', metavar='',nargs='+',
-            help='filter sites by type', default=kDefultGridSiteType)
-        parser.add_argument('-i', '--info', metavar='',nargs='+',
-            help='list of info to show', default=kDefaultGridSiteInfo)
-        return parser
-    
-    @staticmethod
-    def run_parser(args=None):
-        parser = GridSiteInfo.get_parser()
-        args = vars(parser.parse_args(args))
-        args['gpu'] = not args.pop('non_gpu', False)
-        args['active'] = not args.pop('non_active', False)
-        GridSiteInfo.show(**args)
-
     @staticmethod
     def show(name=None, gpu=True, active=True, site_type=kDefultGridSiteType,
         info=kDefaultGridSiteInfo):
