@@ -201,11 +201,9 @@ def get_physical_devices(device_type='GPU'):
     return physical_devices
 
 def get_n_gpu():
-    '''
+    #return len(get_physical_devices(device_type='GPU'))
     import torch
     return torch.cuda.device_count()
-    '''
-    return len(get_physical_devices(device_type='GPU'))
 
 def get_n_cpu():
     return multiprocessing.cpu_count()
